import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from "react";

/* eslint-disable react/forbid-foreign-prop-types */
import { ArgumentError, mergeClasses, throwWhenUnsupportedPropIsProvided } from "@orbit-ui/react-components-shared";
import { Children, cloneElement, forwardRef } from "react";
import { Ref, Button as SemanticButton } from "semantic-ui-react";
import { bool, element, func, object, oneOf, oneOfType, string } from "prop-types";
import { createIconForControl } from "@orbit-ui/react-icons";
import { createLabelFromShorthand, createTagFromShorthand } from "@orbit-ui/react-label";
import { isElement } from "react-is";
import { isNil } from "lodash"; // Sizes constants are duplicated here until https://github.com/reactjs/react-docgen/pull/352 is merged. Otherwise it will not render properly in the docs.

const SIZES = ["tiny", "small", "medium", "large"];
const DEFAULT_SIZE = "medium";
const UNSUPPORTED_PROPS = ["animated", "attached", "color", "labelPosition", "floated", "inverted"];
const propTypes = {
  /**
   * A ghost button doesn't have a background color until it's hovered.
   */
  ghost: bool,

  /**
   * A button can contain an icon.
   */
  icon: element,

  /**
   * An icon can appear on the left or right.
   */
  iconPosition: oneOf(["right", "left"]),

  /**
   * A button can contain a label.
   */
  label: oneOfType([element, object]),

  /**
   * A button can contain a tag.
   */
  tag: oneOfType([element, object]),

  /**
   * A button can be colorless. Use this variant if you need to customize the button.
   */
  naked: bool,

  /**
   * An input can vary in sizes.
   */
  size: oneOf(SIZES),

  /**
   * The HTML button type.
   */
  type: oneOf(["button", "submit", "reset"]),

  /**
   * @ignore
   */
  className: string,

  /**
   * @ignore
   */
  forwardedRef: oneOfType([object, func])
};
const defaultProps = {
  ghost: false,
  iconPosition: "left",
  naked: false,
  size: DEFAULT_SIZE,
  type: "button"
};

function throwWhenMutuallyExclusivePropsAreProvided({
  label,
  tag,
  icon,
  iconPosition
}) {
  if (!isNil(label) && !isNil(icon) && iconPosition === "right") {
    throw new ArgumentError("@orbit/react-button doesn't support having a label and a right positioned icon at the same time.");
  }

  if (!isNil(tag) && !isNil(icon) && iconPosition === "left") {
    throw new ArgumentError("@orbit/react-button doesn't support having a tag and a left positioned icon at the same time.");
  }
}

export function PureButton(props) {
  const {
    naked,
    ghost,
    icon,
    iconPosition,
    label,
    tag,
    size,
    className,
    forwardedRef,
    children
  } = props,
        rest = _objectWithoutProperties(props, ["naked", "ghost", "icon", "iconPosition", "label", "tag", "size", "className", "forwardedRef", "children"]);

  throwWhenUnsupportedPropIsProvided(props, UNSUPPORTED_PROPS, "@orbit-ui/react-button");
  throwWhenMutuallyExclusivePropsAreProvided(props);

  const renderWithRef = () => {
    return React.createElement(Ref, {
      innerRef: forwardedRef
    }, renderButton());
  };

  const renderLabel = () => {
    const defaults = {
      as: "span",
      size: "mini",
      highlight: true
    };

    if (isElement(label)) {
      return cloneElement(label, defaults);
    }

    return createLabelFromShorthand(_objectSpread({}, defaults, {}, label));
  };

  const renderTag = () => {
    const defaults = {
      as: "span",
      size: "mini"
    };

    if (isElement(tag)) {
      return cloneElement(tag, defaults);
    }

    return createTagFromShorthand(_objectSpread({}, defaults, {}, tag));
  };

  const renderContent = () => {
    let left;
    let right;

    if (!isNil(icon)) {
      if (iconPosition === "right") {
        right = createIconForControl(icon, size);
      } else {
        left = createIconForControl(icon, size);
      }
    }

    if (!isNil(label)) {
      right = renderLabel();
    }

    if (!isNil(tag)) {
      left = renderTag();
    }

    if (!isNil(left) || !isNil(right)) {
      return React.createElement(React.Fragment, null, !isNil(left) && left, children, !isNil(right) && right);
    }

    return children;
  };

  const renderButton = () => {
    const hasText = Children.count(children);
    const classes = mergeClasses(naked && "naked", ghost && "ghost", !isNil(icon) && "with-icon", !isNil(icon) && iconPosition === "right" && "with-icon-right", !isNil(label) && "with-label", !isNil(tag) && "with-tag", !hasText && "without-text", className);
    return React.createElement(SemanticButton, Object.assign({
      size: size,
      className: classes
    }, rest), renderContent());
  };

  return isNil(forwardedRef) ? renderButton() : renderWithRef();
}
PureButton.propTypes = propTypes;
PureButton.defaultProps = defaultProps;
export const Button = forwardRef((props, ref) => React.createElement(PureButton, Object.assign({}, props, {
  forwardedRef: ref
}))); // Button.Or is not supported yet.

[PureButton, Button].forEach(x => {
  x.Content = SemanticButton.Content;
  x.Group = SemanticButton.Group;
});

if (!isNil(SemanticButton.propTypes)) {
  SemanticButton.propTypes.size = oneOf(SIZES);
}