import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from "react";
import "./monkey-patch-dropdown-item";
import { DropdownContext } from "./context";
import { DropdownItem } from "./item";
import { LARGE, SMALL, mergeClasses, throwWhenUnsupportedPropIsProvided, useForwardRef } from "@orbit-ui/react-components-shared";
import { Ref, Dropdown as SemanticDropdown } from "semantic-ui-react";
import { any, arrayOf, bool, element, func, number, object, oneOf, oneOfType, shape, string } from "prop-types";
import { forwardRef, useEffect } from "react";
import { isNil } from "lodash"; // Sizes constants are duplicated here until https://github.com/reactjs/react-docgen/pull/352 is merged. Otherwise it will not render properly in the docs.

const SIZES = ["small", "medium", "large"];
const SIZES_CLASSES = {
  [SMALL]: "small",
  [LARGE]: "large"
};
const UNSUPPORTED_PROPS = ["as", "basic", "button", "compact", "additionLabel", "additionPosition", "allowAdditions", "direction", "floating", "header", "item", "icon", "labeled", "multiple", "openOnFocus", "pointing", "searchInput", "selectOnBlur", "selectOnNavigation", "simple"];
const ACTION_SHAPE = {
  content: element,
  className: string
};
const propTypes = {
  /**
   * A dropdown can vary in sizes.
   */
  size: oneOf(SIZES),

  /**
   * Whether or not the dropdown should autofocus on render.
   */
  autofocus: bool,

  /**
   * Delay before trying to autofocus.
   */
  autofocusDelay: number,

  /**
   * A dropdown can have a list of actions.
   */
  actions: arrayOf(shape(ACTION_SHAPE)),

  /**
   * @ignore
   */
  options: arrayOf(any).isRequired,

  /**
   * @ignore
   */
  disabled: bool,

  /**
   * @ignore
   */
  className: string,

  /**
   * @ignore
   */
  forwardedRef: oneOfType([object, func])
};
const defaultProps = {
  autofocus: false
};

function focus(dropdownRef) {
  if (!isNil(dropdownRef.current)) {
    dropdownRef.current.focus();
  }
}

function useAutofocus(autofocus, autofocusDelay, disabled, dropdownRef) {
  useEffect(() => {
    let timeoutId;

    if (autofocus && !disabled) {
      const delay = !isNil(autofocusDelay) ? autofocusDelay : 5;
      timeoutId = setTimeout(() => {
        focus(dropdownRef);
      }, delay);
    }

    return () => {
      if (!isNil(timeoutId)) {
        clearTimeout(timeoutId);
      }
    };
  }, [autofocus, autofocusDelay, disabled, dropdownRef]);
}

const renderAction = (_ref, index) => {
  let {
    className
  } = _ref,
      rest = _objectWithoutProperties(_ref, ["className"]);

  const classes = mergeClasses(className, "action bg-white o-100");
  return _objectSpread({
    className: classes,
    disabled: true,
    key: "action-".concat(index)
  }, rest);
};

export function PureDropdown(props) {
  const {
    size,
    autofocus,
    autofocusDelay,
    actions,
    options,
    disabled,
    className,
    forwardedRef
  } = props,
        rest = _objectWithoutProperties(props, ["size", "autofocus", "autofocusDelay", "actions", "options", "disabled", "className", "forwardedRef"]);

  const [ref, setRef] = useForwardRef(forwardedRef);
  throwWhenUnsupportedPropIsProvided(props, UNSUPPORTED_PROPS, "@orbit-ui/react-dropdown");
  useAutofocus(autofocus, autofocusDelay, disabled, ref);
  const classes = mergeClasses(SIZES_CLASSES[size], className);

  const renderOptions = () => {
    if (!isNil(actions)) {
      return [...options, ...actions.map(renderAction)];
    }

    return options;
  };

  return React.createElement(Ref, {
    innerRef: setRef
  }, React.createElement(DropdownContext.Provider, {
    value: {
      size: size
    }
  }, React.createElement(SemanticDropdown, Object.assign({
    options: renderOptions(),
    selectOnBlur: false,
    selectOnNavigation: false,
    openOnFocus: false,
    disabled: disabled,
    className: classes
  }, rest))));
}
PureDropdown.displayName = "PureDropdown";
PureDropdown.propTypes = propTypes;
PureDropdown.defaultProps = defaultProps;
export const Dropdown = forwardRef((props, ref) => React.createElement(PureDropdown, Object.assign({}, props, {
  forwardedRef: ref
})));
[PureDropdown, Dropdown].forEach(x => {
  x.Divider = SemanticDropdown.Divider;
  x.Header = SemanticDropdown.Header;
  x.Item = DropdownItem;
  x.Menu = SemanticDropdown.Menu;
  x.SearchInput = SemanticDropdown.SearchInput;
});